@@ -18,11 +18,11 @@ def update_series(chart: Chart, *, chart_spec: ChartSpec) -> None:
 def update_series_format(chart_series: _BaseCategorySeries, *, format_spec: SeriesFormatSpec) -> None:
     line_format: LineFormat = chart_series.format.line
 
-    color = format_spec.color
+    color = format_spec._color
     if color is not None:
         line_format.fill.fore_color.rgb = RGBColor(*color)
 
-    dash_style = format_spec.dash_style
+    dash_style = format_spec._dash_style
     if dash_style is not None:
         line_format.dash_style = dash_style
 
