@@ -5,7 +5,7 @@ import pandas as pd
 from more_itertools import partition
 from pandas import DataFrame, Series
 
-from dbnomics_pptx_tools.metadata import FactorySpec, SeriesId, SeriesSpec, ShapeSpec
+from dbnomics_pptx_tools.metadata import SeriesId, SeriesSpec, ShapeSpec
 from dbnomics_pptx_tools.repo import SeriesRepo
 
 logger = daiquiri.getLogger(__name__)
